@@ -91,8 +91,6 @@ class Stack(object):
         self.metadata["CreationTime"] = self.metadata.get("CreationTime") or timestamp_millis()
         # maps resource id to resource state
         self._resource_states = {}
-        # maps resource id to moto resource class instance (TODO: remove in the future)
-        self.moto_resource_statuses = {}
         # list of stack events
         self.events = []
         # list of stack change sets
@@ -937,7 +935,7 @@ def get_template(req_params):
     cs_name = req_params.get("ChangeSetName")
     stack = find_stack(stack_name)
     if cs_name:
-        stack = find_change_set(stack_name, cs_name)
+        stack = find_change_set(stack_name=stack_name, cs_name=cs_name)
     if not stack:
         return stack_not_found_error(stack_name)
     result = {"TemplateBody": json.dumps(stack._template_raw)}
